==> seedsui-react-2.6.2.tgz: package/es/Page/Page.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Page = function (_Component) {
  _inherits(Page, _Component);

  function Page(props) {
    _classCallCheck(this, Page);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {};
    return _this;
  }

  Page.prototype.componentDidMount = function componentDidMount() {};

  Page.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        animation = _props.animation,
        style = _props.style,
        className = _props.className,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['animation', 'style', 'className', 'children']);

    return React.createElement(
      'section',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        }, className: 'page' + (className ? ' ' + className : ''), 'data-animation': animation, style: style }, others),
      children
    );
  };

  return Page;
}(Component);

export { Page as default };
Page.propTypes = process.env.NODE_ENV !== "production" ? {
  style: PropTypes.object,
  className: PropTypes.string,
  animation: PropTypes.string,
  children: PropTypes.node
} : {};

==> seedsui-react-2.7.9.tgz: package/es/Page/Page.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Page = function (_Component) {
  _inherits(Page, _Component);

  function Page(props) {
    _classCallCheck(this, Page);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.state = {};
    return _this;
  }

  Page.prototype.componentDidMount = function componentDidMount() {};

  Page.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        animation = _props.animation,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['animation', 'children']);

    return React.createElement(
      'section',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'page' + (others.className ? ' ' + others.className : ''), 'data-animation': animation }),
      children
    );
  };

  return Page;
}(Component);

export { Page as default };
Page.propTypes = process.env.NODE_ENV !== "production" ? {
  animation: PropTypes.string,
  children: PropTypes.node
} : {};
